@@ -25,7 +25,7 @@ from IPython.display import display
 #
 class ControllerAPI:
     # Constructor
-    def __init__(self, api_key, pt_device_id, api_endpoint='api.us-east-1.mbedcloud.com',async_response_sec=1.0):
+    def __init__(self, api_key, pt_device_id, api_endpoint='api.us-east-1.mbedcloud.com',async_response_sec=0.25):
         # To Do: Lets keep the API Key as protected as possible... 
         self.pelion_api_key = api_key
 
@@ -77,12 +77,14 @@ class ControllerAPI:
             if 'async-responses' in responses_json:
                 for response in responses_json['async-responses']:
                     if response['id'] == req_id:
-                        pelion_command_response = ''
+                        pelion_command_response = {}
                         if 'status' in response:
                             pelion_command_response['status'] = response['status']
                         if 'payload' in response:
                             if response['payload'] != '':
                                 pelion_command_response = json.loads(base64.b64decode(response['payload']))
+                                if 'status' in response:
+                                    pelion_command_response['status'] = response['status']
                         DoPoll = False
             if DoPoll == True:
                 time.sleep(self.async_response_wait_time_sec)
@@ -148,39 +150,54 @@ class ControllerAPI:
     # ListModels
     def pelion_list_models(self):
         req_id = str(uuid.uuid4())
-        self.__pelion_post(req_id, self.pelion_rpc_request_lwmwm_uri, {"jsonrpc":"2.0","id":req_id,"method":"listModels"})
-        return self.pelion_last_cmd_result()
+        result = self.__pelion_post(req_id, self.pelion_rpc_request_lwmwm_uri, {"jsonrpc":"2.0","id":req_id,"method":"listModels"})
+        if result.status_code >=  200 and result.status_code < 300:
+            return self.pelion_last_cmd_result()
+        else:
+            return result
 
     # LoadModel
     def pelion_load_model(self,model_name,s3_filename):
         req_id = str(uuid.uuid4())
-        self.__pelion_post(req_id,self.pelion_rpc_request_lwmwm_uri, {"jsonrpc":"2.0","id":req_id,"method":"loadModel","params":{"name":model_name,"s3_filename":s3_filename}})
-        return self.pelion_last_cmd_result()
+        result = self.__pelion_post(req_id,self.pelion_rpc_request_lwmwm_uri, {"jsonrpc":"2.0","id":req_id,"method":"loadModel","params":{"name":model_name,"s3_filename":s3_filename}})
+        if result.status_code >=  200 and result.status_code < 300:
+            return self.pelion_last_cmd_result()
+        else:
+            return result
 
     # UnloadModel
     def pelion_unload_model(self,model_name):
         req_id = str(uuid.uuid4())
-        self.__pelion_post(req_id,self.pelion_rpc_request_lwmwm_uri, {"jsonrpc":"2.0","id":req_id,"method":"unloadModel","params":{"name":model_name}})
-        return self.pelion_last_cmd_result()
+        result = self.__pelion_post(req_id,self.pelion_rpc_request_lwmwm_uri, {"jsonrpc":"2.0","id":req_id,"method":"unloadModel","params":{"name":model_name}})
+        if result.status_code >=  200 and result.status_code < 300:
+            return self.pelion_last_cmd_result()
+        else:
+            return result
     
     # ReloadModel
     def pelion_reload_model(self,model_name,s3_filename):
         req_id = str(uuid.uuid4())
-        self.__pelion_post(req_id,self.pelion_rpc_request_lwmwm_uri, {"jsonrpc":"2.0","id":req_id,"method":"reloadModel","params":{"name":model_name,"s3_filename":s3_filename}})
-        return self.pelion_last_cmd_result()
+        result = self.__pelion_post(req_id,self.pelion_rpc_request_lwmwm_uri, {"jsonrpc":"2.0","id":req_id,"method":"reloadModel","params":{"name":model_name,"s3_filename":s3_filename}})
+        if result.status_code >=  200 and result.status_code < 300:
+            return self.pelion_last_cmd_result()
+        else:
+            return result
 
     # Predict
     def pelion_predict(self,model_name,input_data_url,output_url):
         req_id = str(uuid.uuid4())
-        self.__pelion_post(req_id,self.pelion_rpc_request_lwmwm_uri,{"jsonrpc":"2.0","id":req_id,"method":"predict","params":{"model_name":model_name,"input_data_url":input_data_url,"output_url":output_url}})
-        return self.pelion_last_cmd_result()
+        result = self.__pelion_post(req_id,self.pelion_rpc_request_lwmwm_uri,{"jsonrpc":"2.0","id":req_id,"method":"predict","params":{"model_name":model_name,"input_data_url":input_data_url,"output_url":output_url}})
+        if result.status_code >=  200 and result.status_code < 300:
+            return self.pelion_last_cmd_result()
+        else:
+            return result
     
     
 #
 # Pelion Sagemaker Notebook Helper Class    
 #
 class MyNotebook:
-    def __init__(self, api_key, device_id, endpoint_api, aws_s3_folder, async_response_sec=1.0):
+    def __init__(self, api_key, device_id, endpoint_api, aws_s3_folder, async_response_sec=0.25):
         # Initialize Sagemaker
         self.sagemaker_init(aws_s3_folder)
         
@@ -218,7 +235,7 @@ class MyNotebook:
         print("IoT Input/Output Folder: " + 's3://{}/{}'.format(bucket, self.iot_folder))
         
     # Pelion Sagemaker Controller Init()
-    def pelion_sagemaker_controller_init(self, api_key, device_id, endpoint_api = 'api.us-east-1.mbedcloud.com', async_response_sec=1.0):
+    def pelion_sagemaker_controller_init(self, api_key, device_id, endpoint_api = 'api.us-east-1.mbedcloud.com', async_response_sec=0.25):
         print("")
         print("Initializing Pelion Sagemaker Controller. Pelion API: " + endpoint_api + " Pelion Sagemaker Edge Agent PT DeviceID: " + device_id)
         
@@ -228,13 +245,21 @@ class MyNotebook:
         # Sync the configuration to match our sagemaker config
         print("")
         print("Syncing Pelion Configuration to match Sagemakers...")
-        self.pelion_api.pelion_set_config('awsS3Bucket',self.bucket)
-        self.pelion_api.pelion_set_config('awsS3ModelsDirectory',self.compilation_output_sub_folder)
-        self.pelion_api.pelion_set_config('awsS3DataDirectory',self.iot_folder)
-        self.pelion_api.pelion_set_config('awsRegion',self.region)
-        print("")
-        print("Current Pelion Configuration:")
-        print(self.pelion_api.pelion_get_config())
+        result = self.pelion_api.pelion_set_config('awsS3Bucket',self.bucket)
+        if result.status_code >=  200 and result.status_code < 300:
+            result = self.pelion_api.pelion_set_config('awsS3ModelsDirectory',self.compilation_output_sub_folder)
+            if result.status_code >=  200 and result.status_code < 300:
+                result = self.pelion_api.pelion_set_config('awsS3DataDirectory',self.iot_folder)
+                if result.status_code >=  200 and result.status_code < 300:
+                    result = self.pelion_api.pelion_set_config('awsRegion',self.region)
+        if result.status_code >=  200 and result.status_code < 300:
+            print("")
+            print("Configuration Sync SUCCESS. Current Pelion Configuration:")
+            print(self.pelion_api.pelion_get_config())
+        else:
+            print("")
+            print("Configuration Sync FAILED with code: " + str(result.status_code))
+            print("Please confirm Edge Agent PT DeviceID and Edge gateway availability and retry...")
             
     # Save off the model
     def save_model(self, model_basename):
